#ifndef _ROXMENU_H
#define _ROXMENU_H

typedef enum {
	GROUPS_ON_BOTTOM,
	GROUPS_ON_TOP
} RoxMenuGrouping;

/* Data type for menu with directory change tracking. */
typedef struct {
	gchar *path;
	GtkWidget *visible_item;
	GtkWidget *visible_menu; 
	GtkWidget *sep;
	time_t modtime;          /* Last mod time of path at last update */
	GList *dir_subdirs;      /* List of (RoxMenuDir*) */
	GList *dir_contents;     /* List of (RoxMenuItem*) */
	gboolean toplevel;       /* Dir is not a submenu => 
	                            visible_item always equals NULL. */
	gboolean is_updating;    /* Is the menudir being updated? */
	RoxMenuGrouping dir_grouping;  /* Where to put directory entries. */
	gboolean show_files;     /* Do we show regular files? */
} RoxMenuDir;

/* Struct for menu items, including AppDirs and regular files. */
typedef struct {
	gchar *path;
	GtkWidget *visible_item;
} RoxMenuItem;

/* Menu object functions. */
RoxMenuDir *menudir_new(const char *path);
RoxMenuDir *menudir_toplevel_new(const char *path);
void menudir_destroy(RoxMenuDir *mendir);
void menudir_update(RoxMenuDir *mendir);
gboolean menudir_is_empty(RoxMenuDir *dir);
void menudir_set_grouping(RoxMenuDir *dir, RoxMenuGrouping mode, 
                          gboolean recursive);
void menudir_set_show_files(RoxMenuDir *dir, gboolean show, 
                            gboolean recursive);
									 
/* Item object functions. */
RoxMenuItem *menuitem_new(const char *path);
void menuitem_destroy(RoxMenuItem *item);

#endif
